==> TextImage-1.0.0.tar.gz: TextImage/atopia/textimage/TextImage.py <==
# File: TextImage.py
#
# Copyright (c) 2006 by Atopia VOF, Netherlands, http://www.atopia.nl
# Generator: ArchGenXML Version 1.4.1
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Atopia <info@atopia.nl>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from Products.TextImage.config import *

# additional imports from tagged value 'import'
from Products.ATColorPickerWidget.ColorPickerWidget import ColorPickerWidget


from Products.CMFCore.utils import UniqueObject

    
##code-section module-header #fill in your manual code here
import os
import DateTime
import PIL.Image
import PIL.ImageDraw
import PIL.ImageFont
from zLOG import LOG, DEBUG, INFO, WARNING, ERROR
##/code-section module-header

schema = Schema((

    StringField(
        name='DefaultText',
        default="Atopia.nl",
        widget=StringWidget(
            label='Defaulttext',
            label_msgid='TextImage_label_DefaultText',
            i18n_domain='TextImage',
        ),
        required=1
    ),

    StringField(
        name='DefaultAlign',
        default="left",
        widget=SelectionWidget(
            label='Defaultalign',
            label_msgid='TextImage_label_DefaultAlign',
            i18n_domain='TextImage',
        ),
        vocabulary=['left', 'center', 'right']
    ),

    IntegerField(
        name='DefaultFontSize',
        default="24",
        widget=IntegerWidget(
            label='Defaultfontsize',
            label_msgid='TextImage_label_DefaultFontSize',
            i18n_domain='TextImage',
        ),
        required=1
    ),

    StringField(
        name='DefaultFontColor',
        default="#B3DC20",
        widget=ColorPickerWidget
        (
            label='Defaultfontcolor',
            label_msgid='TextImage_label_DefaultFontColor',
            i18n_domain='TextImage',
        ),
        required=1
    ),

    StringField(
        name='DefaultBackgroundColor',
        default="#FFFFFF",
        widget=ColorPickerWidget
        (
            label='Defaultbackgroundcolor',
            label_msgid='TextImage_label_DefaultBackgroundColor',
            i18n_domain='TextImage',
        ),
        required=1
    ),

    IntegerField(
        name='DefaultBackgroundWidth',
        default="128",
        widget=IntegerWidget(
            label='Defaultbackgroundwidth',
            label_msgid='TextImage_label_DefaultBackgroundWidth',
            i18n_domain='TextImage',
        ),
        required=1
    ),

    IntegerField(
        name='DefaultBackgroundHeight',
        default="64",
        widget=IntegerWidget(
            label='Defaultbackgroundheight',
            label_msgid='TextImage_label_DefaultBackgroundHeight',
            i18n_domain='TextImage',
        ),
        required=1
    ),

),
)

##code-section after-local-schema #fill in your manual code here
##/code-section after-local-schema

TextImage_schema = OrderedBaseFolderSchema.copy() + \
    schema.copy()

##code-section after-schema #fill in your manual code here
TextImage_schema["title"].widget.visible = {"view" : "invisible", "edit" : "invisible"}
TextImage_schema["title"].required = 0
TextImage_schema["description"].widget.visible = {"view" : "invisible", "edit" : "invisible"}
##/code-section after-schema

class TextImage(UniqueObject, OrderedBaseFolder):
    security = ClassSecurityInfo()
    __implements__ = (getattr(UniqueObject,'__implements__',()),) + (getattr(OrderedBaseFolder,'__implements__',()),)

    # This name appears in the 'add' box
    archetype_name = 'TextImage'

    meta_type = 'TextImage'
    portal_type = 'TextImage'
    allowed_content_types = ['Font']
    filter_content_types = 1
    global_allow = 0
    allow_discussion = False
    content_icon = 'TextImage.gif'
    immediate_view = 'base_view'
    default_view = 'base_view'
    suppl_views = ()
    typeDescription = "TextImage"
    typeDescMsgId = 'description_edit_textimage'
    #toolicon = 'TextImage.gif'

    schema = TextImage_schema

    ##code-section class-header #fill in your manual code here
    ##/code-section class-header


    # tool-constructors have no id argument, the id is fixed
    def __init__(self, id=None):
        OrderedBaseFolder.__init__(self,'portal_textimage')
       
        ##code-section constructor-footer #fill in your manual code here
        self.description = 'Portal tool that generates images with text.'
        ##/code-section constructor-footer


    # Methods

    # Manually created methods
    security.declarePublic('generateTextImage')
    def generateTextImage(self, RESPONSE, text=None, align=None, fontId=None, fontSize=None, fontColor=None, backgroundColor=None, backgroundWidth=None, backgroundHeight=None):
        if not text:
            text = self.getDefaultText()
        text = text.decode('utf-8')

        if not align:
            align = self.getDefaultAlign()

        fontIds = self.objectIds()
        if not fontIds:
            LOG('TextImage', DEBUG, 'no fonts available, returning')
            return
        else:
            if fontId:
                if not fontId in self.objectIds():
                    LOG('TextImage', DEBUG, 'fontId %s not available, using first available fontId %s as default' %(fontId, fontIds[0]))
                    fontId = fontIds[0]
                else:
                    LOG('TextImage', DEBUG, 'using fontId %s' %fontId)
            else:
                LOG('TextImage', DEBUG, 'no fontId specified, using first available fontId %s as default' %fontIds[0])
                fontId = fontIds[0]

        if not fontSize:
            fontSize = self.getDefaultFontSize()

        if not fontColor:
            fontColor = self.getDefaultFontColor()
        else:
            fontColor = '#%s' %fontColor    

        if not backgroundColor:
            backgroundColor = self.getDefaultBackgroundColor()
        else:
            backgroundColor = '#%s' %backgroundColor    
    
        if not backgroundWidth:
            backgroundWidth = self.getDefaultBackgroundWidth()
        else:
            backgroundWidth = int(backgroundWidth)
    
        if not backgroundHeight:
            backgroundHeight = self.getDefaultBackgroundHeight()
        else:
            backgroundHeight = int(backgroundHeight)

        LOG('TextImage', DEBUG, 'generating textimage for text=%s, align=%s, fontId=%s, fontSize=%s, fontColor=%s, backgroundColor=%s, backgroundWidth=%s, backgroundHeight=%s' %(text, align, fontId, fontSize, fontColor, backgroundColor, backgroundWidth, backgroundHeight))
        
        timestamp = DateTime.DateTime().strftime('%s')

        fontFileName = '/tmp/' + fontId
        if not os.path.isfile(fontFileName):
            self[fontId].writeFont()
        font = PIL.ImageFont.truetype(fontFileName, int(fontSize))

        image = PIL.Image.new(mode='RGB', size=(backgroundWidth,backgroundHeight), color=backgroundColor)
        image.info['quality'] = 100;
        draw = PIL.ImageDraw.Draw(image)
        x, y = draw.textsize(text, font=font)
        if align == 'center':
            x = (backgroundWidth - x) / 2
        else:
            if align == 'right':
                x = backgroundWidth - x;
            else: # left
                x = 0;
        y = (backgroundHeight - y) / 2
        draw.text((x,y), text, font=font, fill=fontColor)

        imageFileName = '/tmp/image-' + fontId + '-' + timestamp + '.png'
        image.save(imageFileName, quality=100)

        imageFile = open(imageFileName, 'r')
        imageString = imageFile.read()
        imageFile.close()

        # handy code for storing inside an ImageField
        # self.getField('DefaultImage').set(self, imageFile)
        # note that it is post open and pre close, do not do a read

        os.remove(imageFileName)

        RESPONSE.setHeader('Content-Type', 'image/png')
        RESPONSE.setHeader('Content-Length', len(imageString))

        return imageString

registerType(TextImage,PROJECTNAME)
# end of class TextImage

##code-section module-footer #fill in your manual code here
##/code-section module-footer

==> TextImage-1.0.1.tar.gz: TextImage/atopia/textimage/TextImage.py <==
# File: TextImage.py
#
# Copyright (c) 2006 by Atopia VOF, Netherlands, http://www.atopia.nl
# Generator: ArchGenXML Version 1.4.1
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Atopia <info@atopia.nl>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from Products.TextImage.config import *

# additional imports from tagged value 'import'
from Products.ATColorPickerWidget.ColorPickerWidget import ColorPickerWidget
from Products.CMFCore.utils import getToolByName


from Products.CMFCore.utils import UniqueObject

    
##code-section module-header #fill in your manual code here
import os
import DateTime
import PIL.Image
import PIL.ImageDraw
import PIL.ImageFont
from zLOG import LOG, DEBUG, INFO, WARNING, ERROR
##/code-section module-header

schema = Schema((

    StringField(
        name='DefaultText',
        default="Atopia.nl",
        widget=StringWidget(
            label='Defaulttext',
            label_msgid='TextImage_label_DefaultText',
            i18n_domain='TextImage',
        ),
        required=1
    ),

    StringField(
        name='DefaultAlign',
        default="left",
        widget=SelectionWidget(
            label='Defaultalign',
            label_msgid='TextImage_label_DefaultAlign',
            i18n_domain='TextImage',
        ),
        vocabulary=['left', 'center', 'right']
    ),

    IntegerField(
        name='DefaultFontSize',
        default="24",
        widget=IntegerWidget(
            label='Defaultfontsize',
            label_msgid='TextImage_label_DefaultFontSize',
            i18n_domain='TextImage',
        ),
        required=1
    ),

    StringField(
        name='DefaultFontColor',
        default="#B3DC20",
        widget=ColorPickerWidget
        (
            label='Defaultfontcolor',
            label_msgid='TextImage_label_DefaultFontColor',
            i18n_domain='TextImage',
        ),
        required=1
    ),

    StringField(
        name='DefaultBackgroundColor',
        default="#FFFFFF",
        widget=ColorPickerWidget
        (
            label='Defaultbackgroundcolor',
            label_msgid='TextImage_label_DefaultBackgroundColor',
            i18n_domain='TextImage',
        ),
        required=1
    ),

    IntegerField(
        name='DefaultBackgroundWidth',
        default="128",
        widget=IntegerWidget(
            label='Defaultbackgroundwidth',
            label_msgid='TextImage_label_DefaultBackgroundWidth',
            i18n_domain='TextImage',
        ),
        required=1
    ),

    IntegerField(
        name='DefaultBackgroundHeight',
        default="64",
        widget=IntegerWidget(
            label='Defaultbackgroundheight',
            label_msgid='TextImage_label_DefaultBackgroundHeight',
            i18n_domain='TextImage',
        ),
        required=1
    ),

),
)

##code-section after-local-schema #fill in your manual code here
##/code-section after-local-schema

TextImage_schema = OrderedBaseFolderSchema.copy() + \
    schema.copy()

##code-section after-schema #fill in your manual code here
TextImage_schema["title"].widget.visible = {"view" : "invisible", "edit" : "invisible"}
TextImage_schema["title"].required = 0
TextImage_schema["description"].widget.visible = {"view" : "invisible", "edit" : "invisible"}
##/code-section after-schema

class TextImage(UniqueObject, OrderedBaseFolder):
    security = ClassSecurityInfo()
    __implements__ = (getattr(UniqueObject,'__implements__',()),) + (getattr(OrderedBaseFolder,'__implements__',()),)

    # This name appears in the 'add' box
    archetype_name = 'TextImage'

    meta_type = 'TextImage'
    portal_type = 'TextImage'
    allowed_content_types = ['Font']
    filter_content_types = 1
    global_allow = 0
    allow_discussion = False
    content_icon = 'TextImage.gif'
    immediate_view = 'base_view'
    default_view = 'base_view'
    suppl_views = ()
    typeDescription = "TextImage"
    typeDescMsgId = 'description_edit_textimage'
    #toolicon = 'TextImage.gif'

    schema = TextImage_schema

    ##code-section class-header #fill in your manual code here
    ##/code-section class-header


    # tool-constructors have no id argument, the id is fixed
    def __init__(self, id=None):
        OrderedBaseFolder.__init__(self,'portal_textimage')
        self.setTitle('TextImage')       

        ##code-section constructor-footer #fill in your manual code here
        self.description = 'Portal tool that generates images with text.'
        ##/code-section constructor-footer


    # tool should not appear in portal_catalog
    def at_post_edit_script(self):
        self.unindexObject()

        ##code-section post-edit-method-footer #fill in your manual code here
        ##/code-section post-edit-method-footer


    # Methods

    # Manually created methods
    security.declarePublic('generateTextImage')
    def generateTextImage(self, RESPONSE, text=None, align=None, fontId=None, fontSize=None, fontColor=None, backgroundColor=None, backgroundWidth=None, backgroundHeight=None):
        if not text:
            text = self.getDefaultText()
        text = text.decode('utf-8')

        if not align:
            align = self.getDefaultAlign()

        font = None
        fonts = self.objectValues(['Font',])
        if not fonts:
            LOG('TextImage', DEBUG, 'no fonts available, returning')
            return
        if fontId:
            for f in fonts:
                if f.id == fontId:
                    font = f
                    fontId = font.id
        if not font or not fontId:
            font = fonts[0]
            fontId = font.id
            LOG('TextImage', WARNING, 'no or wrong fontId specified, using first available fontId %s as default' %fontId)

        if not fontSize:
            fontSize = self.getDefaultFontSize()

        if not fontColor:
            fontColor = self.getDefaultFontColor()
        else:
            fontColor = '#%s' %fontColor    

        if not backgroundColor:
            backgroundColor = self.getDefaultBackgroundColor()
        else:
            backgroundColor = '#%s' %backgroundColor    
    
        if not backgroundWidth:
            backgroundWidth = self.getDefaultBackgroundWidth()
        else:
            backgroundWidth = int(backgroundWidth)
    
        if not backgroundHeight:
            backgroundHeight = self.getDefaultBackgroundHeight()
        else:
            backgroundHeight = int(backgroundHeight)

        LOG('TextImage', DEBUG, 'generating textimage for text=%s, align=%s, fontId=%s, fontSize=%s, fontColor=%s, backgroundColor=%s, backgroundWidth=%s, backgroundHeight=%s' %(text, align, fontId, fontSize, fontColor, backgroundColor, backgroundWidth, backgroundHeight))
        
        timestamp = DateTime.DateTime().strftime('%s')

        fss_tool = getToolByName(self, 'portal_fss')
        fontFileName = fss_tool.getStoragePath() + '/' + font.UID() + '_File'
        if not os.path.isfile(fontFileName):
            LOG('TextImage', ERROR, 'could not find font with id %s on file system as file %s' %(fontId, fontFileName))
            return
        font = PIL.ImageFont.truetype(fontFileName, int(fontSize))

        image = PIL.Image.new(mode='RGB', size=(backgroundWidth,backgroundHeight), color=backgroundColor)
        image.info['quality'] = 100;
        draw = PIL.ImageDraw.Draw(image)
        x, y = draw.textsize(text, font=font)
        if align == 'center':
            x = (backgroundWidth - x) / 2
        else:
            if align == 'right':
                x = backgroundWidth - x;
            else: # left
                x = 0;
        y = (backgroundHeight - y) / 2
        draw.text((x,y), text, font=font, fill=fontColor)

        imageFileName = '/tmp/image-' + fontId + '-' + timestamp + '.png'
        image.save(imageFileName, quality=100)

        imageFile = open(imageFileName, 'r')
        imageString = imageFile.read()
        imageFile.close()

        # handy code for storing inside an ImageField
        # self.getField('DefaultImage').set(self, imageFile)
        # note that it is post open and pre close, do not do a read

        os.remove(imageFileName)

        RESPONSE.setHeader('Content-Type', 'image/png')
        RESPONSE.setHeader('Content-Length', len(imageString))

        return imageString

registerType(TextImage,PROJECTNAME)
# end of class TextImage

##code-section module-footer #fill in your manual code here
##/code-section module-footer
